@@ -5,7 +5,7 @@
 #  LINUX, a cdrom drive and an active internet connection in order
 #  to do that.
 #
-#  (c) 2004 Armin Obersteiner <armin@xos.net>
+#  (c) 2002 Armin Obersteiner <armin@xos.net>
 #
 #  LICENSE
 #
@@ -20,8 +20,6 @@
 
 package CDDB_get;
 
-use Config;
-
 use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $debug);
 
@@ -35,14 +33,13 @@ require Exporter;
   get_cddb
   get_discids
 );
-$VERSION = '2.28.1';
+$VERSION = '2.01';
 
 use Fcntl;
 use IO::Socket;
 use Data::Dumper qw(Dumper);
-use MIME::Base64 qw(encode_base64);
 
-$debug=1;
+#$debug=1;
 
 # setup for linux, solaris x86, solaris spark
 # you freebsd guys give me input 
@@ -67,31 +64,20 @@ my $CDROM_MSF=0x02;
 # default config
 
 my $CDDB_HOST = "freedb.freedb.org";
-my $CDDB_PORT = 8880;
+my $CDDB_PORT = 888;
 my $CDDB_MODE = "cddb";
 my $CD_DEVICE = "/dev/cdrom";
 
 my $HELLO_ID  = "root nowhere.com fastrip 0.77";
-my $PROTO_VERSION = 5;
 
 # endian check
 
 my $BIG_ENDIAN = unpack("h*", pack("s", 1)) =~ /01/;
 
 if($BIG_ENDIAN) { 
-  print STDERR "[big endian] " if $debug;
+  print STDERR "[big endian]\n" if $debug;
 } else {
-  print STDERR "[little endian] " if $debug;
-}
-
-# 64bit pointer check
-
-my $BITS_64 = $Config{ptrsize} == 8 ? 1 : 0;
-
-if($BITS_64) {
-  print STDERR "[64 bit]\n" if $debug;
-} else {
-  print STDERR "[32 bit]\n" if $debug;
+  print STDERR "[little endian]\n" if $debug;
 }
 
 if($os eq "SunOS") {
@@ -117,10 +103,6 @@ if($os eq "SunOS") {
   $CDROMREADTOCHDR=0x40046304;
   $CDROMREADTOCENTRY=0xc0086305;
 
-  if($BITS_64) {
-    $CDROMREADTOCENTRY=0xc0106305;
-  }
-
   $CD_DEVICE="/dev/cd0a";
 
   if($os eq "OpenBSD") {
@@ -130,17 +112,16 @@ if($os eq "SunOS") {
 
 sub read_toc {
   my $device=shift;
-  my $tochdr=chr(0) x 16;
+  my $tochdr="";
 
-  sysopen (CD,$device, O_RDONLY | O_NONBLOCK) or die "cannot open cdrom [$!] [$device]";
-  ioctl(CD, $CDROMREADTOCHDR, $tochdr) or die "cannot read toc [$!] [$device]";
+  sysopen (CD,$device, O_RDONLY | O_NONBLOCK) or die "cannot open cdrom [$!]";
+  ioctl(CD, $CDROMREADTOCHDR, $tochdr) or die "cannot read toc [$!]";
   my ($start,$end);
   if($os =~ /BSD/) {
     ($start,$end)=unpack "CC",(substr $tochdr,2,2);
   } else {
     ($start,$end)=unpack "CC",$tochdr;
   }
-  print STDERR "start track: $start, end track: $end\n" if $debug;
 
   my @tracks=();
 
@@ -163,21 +144,11 @@ sub read_toc {
     my $size_lo=$size & 255;      
 
     if($BIG_ENDIAN) {
-      if($BITS_64) {
-        # better but just perl >= 5.8.0
-        # $tocentry=pack "CCCCx![P]P", $CDROM_MSF,0,$size_hi,$size_lo,$toc; 
-        $tocentry=pack "CCCCxxxxP", $CDROM_MSF,0,$size_hi,$size_lo,$toc; 
-      } else {
-        $tocentry=pack "CCCCP8l", $CDROM_MSF,0,$size_hi,$size_lo,$toc; 
-      }
+      $tocentry=pack "CCCCP8l", $CDROM_MSF,0,$size_hi,$size_lo,$toc; 
     } else {
-      if($BITS_64) {
-        $tocentry=pack "CCCCxxxxP", $CDROM_MSF,0,$size_lo,$size_hi,$toc; 
-      } else {
-        $tocentry=pack "CCCCP8l", $CDROM_MSF,0,$size_lo,$size_hi,$toc; 
-      }
+      $tocentry=pack "CCCCP8l", $CDROM_MSF,0,$size_lo,$size_hi,$toc; 
     }
-    ioctl(CD, $CDROMREADTOCENTRY, $tocentry) or die "cannot read track info [$!] [$device]";
+    ioctl(CD, $CDROMREADTOCENTRY, $tocentry) or die "cannot read track info [$!]";
   }
 
   my $count=0;
@@ -185,8 +156,7 @@ sub read_toc {
     my ($min,$sec,$frame);
     unless($os =~ /BSD/) {
       $tocentry=pack "CCC", $i,0,$CDROM_MSF;
-      $tocentry.=chr(0) x 16;
-      ioctl(CD, $CDROMREADTOCENTRY, $tocentry) or die "cannot read track $i info [$!] [$device]";
+      ioctl(CD, $CDROMREADTOCENTRY, $tocentry) or die "cannot read track $i info [$!]";
       ($min,$sec,$frame)=unpack "CCCC", substr($tocentry,4,4);
     } else {
       ($min,$sec,$frame)=unpack "CCC", substr($toc,$count+5,3);
@@ -265,16 +235,12 @@ sub get_cddb {
   my $multi = $config->{multi};
   $input = 0 if $multi;
 
-  print STDERR Dumper($config) if $debug;
-
   $CDDB_HOST = $config->{CDDB_HOST} if (defined($config->{CDDB_HOST}));
   $CDDB_PORT = $config->{CDDB_PORT} if (defined($config->{CDDB_PORT}));
   $CDDB_MODE = $config->{CDDB_MODE} if (defined($config->{CDDB_MODE}));
   $CD_DEVICE = $config->{CD_DEVICE} if (defined($config->{CD_DEVICE}));
   $HELLO_ID  = $config->{HELLO_ID} if (defined($config->{HELLO_ID}));
-  $PROTO_VERSION  = $config->{PROTO_VERSION} if (defined($config->{PROTO_VERSION}));
   my $HTTP_PROXY = $config->{HTTP_PROXY} if (defined($config->{HTTP_PROXY}));
-  my $FW=1 if (defined($config->{FW}));
  
   if(defined($diskid)) {
     $id=$diskid->[0];
@@ -296,13 +262,7 @@ sub get_cddb {
   for (my $i=0; $i<$total ;$i++) {
       $query.=" $toc->[$i]->{frames}";
   }
-
-  # this was to old total calculation, does not work too well, its included if new version makes problems
-  # $query.=" ". int(($toc->[$total]->{frames}-$toc->[0]->{frames})/75);
-
-  $query.=" ". int(($toc->[$total]->{frames})/75);
-
-  print Dumper($toc) if $debug;
+  $query.=" ". int(($toc->[$total]->{frames}-$toc->[0]->{frames})/75);
 
   if ($CDDB_MODE eq "cddb") {
     print STDERR "cddb: connecting to $CDDB_HOST:$CDDB_PORT\n" if $debug;
@@ -318,18 +278,9 @@ sub get_cddb {
     print $socket "cddb hello $HELLO_ID\n";
 
     $return=<$socket>;
-    print STDERR "hello return: $return" if $debug;
     unless ($return =~ /^2\d\d\s+/) {
       die "handshake error at cddb db: $CDDB_HOST:$CDDB_PORT";
     }
-
-    print $socket "proto $PROTO_VERSION\n";
-
-    $return=<$socket>;
-    print STDERR "proto return: $return" if $debug;
-    unless ($return =~ /^2\d\d\s+/) {
-      die "protokoll mismatch error at cddb db: $CDDB_HOST:$CDDB_PORT";
-    }
  
     print STDERR "cddb: sending: $query\n" if $debug;
     print $socket "$query\n";
@@ -344,24 +295,17 @@ sub get_cddb {
     my $id=$HELLO_ID;
     $id =~ s/ /+/g;
 
-    my $url = "/~cddb/cddb.cgi?cmd=$query2&hello=$id&proto=$PROTO_VERSION";
+    my $url = "/~cddb/cddb.cgi?cmd=$query2&hello=$id&proto=1";
 
     my $host=$CDDB_HOST;
     my $port=80;
 
-    my ($user,$pass);
-
     if($HTTP_PROXY) {
-      if($HTTP_PROXY =~ /^(http:\/\/|)(.+?):(.+)\@(.+?):(.+)/) {
-        $user=$2;
-        $pass=$3;
-        $host=$4;
-        $port=$5;
-      } elsif($HTTP_PROXY =~ /^(http:\/\/|)(.+?):(\d+)/) {
+      if($HTTP_PROXY =~ /^(http:\/\/|)(.+?):(\d+)/) {
         $host=$2;
         $port=$3;
+        $url="http://$CDDB_HOST".$url." HTTP/1.0\n";
       }
-      $url="http://$CDDB_HOST".$url." HTTP/1.0";
     }
 
     print STDERR "cddb: connecting to $host:$port\n" if $debug;
@@ -372,14 +316,6 @@ sub get_cddb {
     print STDERR "cddb: http send: GET $url\n" if $debug;
     print $socket "GET $url\n";
 
-    if($user) {
-      my $cred = encode_base64("$user:$pass");
-      print $socket "Proxy-Authorization: Basic $cred\n";
-    }
-
-    print $socket "\n";
-    print $socket "\n" if $FW;
-
     if($HTTP_PROXY) {
       while(<$socket> =~ /^\S+/){};
     }
@@ -463,7 +399,6 @@ sub get_cddb {
     my %cd=();
     $cd{artist}=$artist;
     chomp $title;
-    $title =~ s/\r//g;
     $cd{title}=$title;
     $cd{cat}=$cat;
     $cd{id}=$id;
@@ -493,24 +428,17 @@ sub get_cddb {
       my $id=$HELLO_ID;
       $id =~ s/ /+/g;
 
-      my $url = "/~cddb/cddb.cgi?cmd=$query2&hello=$id&proto=$PROTO_VERSION";
+      my $url = "/~cddb/cddb.cgi?cmd=$query2&hello=$id&proto=1";
 
       my $host=$CDDB_HOST;
       my $port=80;
 
-      my ($user,$pass);
-
       if($HTTP_PROXY) {
-        if($HTTP_PROXY =~ /^(http:\/\/|)(.+?):(.+)\@(.+?):(.+)/) {
-          $user=$2;
-          $pass=$3;
-          $host=$4;
-          $port=$5;
-        } elsif($HTTP_PROXY =~ /^(http:\/\/|)(.+?):(\d+)/) {
+        if($HTTP_PROXY =~ /^(http:\/\/|)(.+?):(\d+)$/) {
           $host=$2;
           $port=$3;
+          $url="http://$CDDB_HOST".$url." HTTP/1.0\n";
         }
-        $url="http://$CDDB_HOST".$url." HTTP/1.0";
       }
 
       print STDERR "cddb: connecting to $host:$port\n" if $debug;
@@ -521,14 +449,6 @@ sub get_cddb {
       print STDERR "cddb: http send: GET $url\n" if $debug;
       print $socket "GET $url\n";
 
-      if($user) {
-        my $cred = encode_base64("$user:$pass");
-        print $socket "Proxy-Authorization: Basic $cred\n";
-      }
-
-      print $socket "\n";
-      print $socket "\n" if $FW;
-
       if($HTTP_PROXY) {
         while(<$socket> =~ /^\S+/){};
       }
@@ -542,19 +462,6 @@ sub get_cddb {
       die "unkown mode: $CDDB_MODE for querying cddb";
     }
 
-    # xmcd
-    #
-    # Track frame offsets:
-    #	150
-    # ...
-    #	210627
-    #
-    # Disc length: 2952 seconds
-    #
-    # Revision: 1
-    # Submitted via: xmcd 2.0
-    #
-
     for(@lines) {
       last if(/^\./);
       next if(/^\d\d\d/);
@@ -570,15 +477,7 @@ sub get_cddb {
         } else {
           $cd{track}[$1]=$cd{track}[$1].$t;
         }
-      } elsif(/^DYEAR=\s*(\d+)/) {
-        $cd{'year'} = $1;
-      } elsif(/^DGENRE=\s*(\S+.*)/) {
-        my $t = $1;
-        chop $t;
-        $cd{'genre'} = $t;
-      } elsif(/^\#\s+Revision:\s+(\d+)/) {
-        $cd{'revision'} = $1;
-      }
+      } 
     }
 
     $cd{tno}=$#{$cd{track}}+1;
@@ -679,12 +578,12 @@ author, who can be contacted at armin@xos.net
 
 =head1 AUTHOR & COPYRIGHT
 
-(c) 2003 Armin Obersteiner <armin(at)xos(dot)net>
+(c) 2002 Armin Obersteiner <armin(at)xos(dot)net>
 
 =head1 SEE ALSO
 
-perl(1), Linux: F</usr/include/linux/cdrom.h>, 
-Solaris, *BSD: F</usr/include/sys/cdio.h>.
+perl(1), Linux: <file:/usr/include/linux/cdrom.h>, 
+Solaris: <file:/usr/include/sys/cdio.h>.
 
 =cut
 
